/**
 * Created: 04/10/2011
 * Name: X4H Advanced Search
 */
function X4HASearch(fields, filters, options, sort) {
    // XML Constructor
    this.fields = (fields != null ? (fields.length > 0 ? fields : []) : []);
    this.filters = (filters != null ? (filters.length > 0 ? filters : []) : []);
    this.options = (options != null ? options : {});
    this.sort = (sort != null ? (sort.length > 0 ? sort : []) : []);
    
    // Adds a field to the search object
    this.addField = function(field) {
        this.fields.push(field);
        return this;
    };
    
    // Adds a filter to the search object
    this.addFilter = function(field, comparison, value1, value2) {
        var filter = {
            name: field,
            comparison: comparison,
            value1: value1,
            value2: value2
        };
        
        if(value2 == null) {
            delete filter.value2;
        }
        
        this.filters.push(filter);
        return this;
    };
    
    // Adds an option to the search object
    this.addOption = function(type, value) {
        if(!this.options[type]) {
            this.options[type] = value;
        }
        return this;
    };
    
    // Adds a sort value to the search object
    this.addSort = function(field, direction) {
        if(direction == null) {
            direction = 'asc';
        }
        var sort = {
            name: field, 
            direction: direction
        };
        
        this.sort.push(sort);
        return this;
    };
    
    
    // Creates an XML string to make an advanced search 
    this.getXML = function() {
        var fieldsXML = '';
        var filtersXML = '';
        var optionsXML = '';
        var sortXML = '';
        
        
        if(this.fields.length > 0) {            
            $.each(this.fields, function(k, val) {
                fieldsXML += '<field><name>' + val + '</name></field>';
            });
            fieldsXML += '<summaryField><name>count auditcount</name></summaryField>';
        }

        if(this.filters.length > 0) {
            $.each(this.filters, function(id, filter) {
                filtersXML += '<filter>';
                $.each(filter, function(k, v) {
                    filtersXML += '<' + k + '>' + v + '</' + k + '>';
                });
                filtersXML += '</filter>';
            });
        }
        
        //console.log(this.options);
        
        
        optionsXML += '<options>';
        if(typeof this.options.rows !== undefined) {
        	optionsXML += '<rows>' + this.options.rows + '</rows>';
        }
        
        if(typeof this.options.startrow !== undefined) {
        	optionsXML += '<startrow>' + this.options.startrow + '</startrow>';
        }
        
        if(typeof this.options.rf === undefined) {
        	optionsXML += '<rf>JSON</rf>';
        }
        
        optionsXML += '</options>';
        
        
        if(this.sort.length > 0) {
        	//sortXML = '<sort>';
            $.each(this.sort, function(k,v) {
                
                sortXML += '<sort><name>' + v.name + '</name><direction>' + v.direction + '</direction></sort>';
            });
            //sortXML +='</sort>';
        }
        
        
        var oXML = '<advancedSearch>' + fieldsXML + filtersXML + optionsXML + sortXML + '</advancedSearch>';
        return oXML;
    };
}